<?php
/**
 * Buconz Starter functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Buconz Starter
 */
if ( ! defined( 'BUCONZ_STARTER_S_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( 'BUCONZ_STARTER_S_VERSION', '1.0.1' );
}

if ( ! function_exists( 'buconz_starter_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function buconz_starter_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on buconz, use a find and replace
		 * to change 'buconz-starter' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'buconz-starter', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// Theme Supports
		add_image_size( 'buconz-starter-blog-thumb', '500', '378', true );
		add_image_size( 'buconz-starter-blog-single-thumb', '1000', '500', true );
		add_image_size( 'buconz-starter-service-thumb', '370', '315', true );
		add_image_size( 'buconz-starter-team-thumb', '330', '310', true );
		
		
			// Register Nav Menu
		register_nav_menus( array(
			'menu-1' => esc_html__( 'Primary', 'buconz-starter' ),
		) );
		register_nav_menus( array(
			'menu-2' => esc_html__( 'footer-menu', 'buconz-starter' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
			'navigation-widgets',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'buconz_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );
      
		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
		
		// Supports for blocks
		add_theme_support( 'align-wide' );
		add_theme_support( 'editor-styles' );
		add_theme_support( 'wp-block-styles' );
	}
endif;
add_action( 'after_setup_theme', 'buconz_starter_setup' );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function buconz_starter_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Blog Sidebar', 'buconz-starter' ),
		'id'            => 'buconz-starter-blog-sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'buconz-starter' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Blog Archive Sidebar', 'buconz-starter' ),
		'id'            => 'buconz-starter-blog-archive-sidebar',
		'description'   => esc_html__( 'Add archive blog widgets here.', 'buconz-starter' ),
		'before_widget' => '<div id="%1$s" class="single-widget widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Blog Single Sidebar', 'buconz-starter' ),
		'id'            => 'buconz-starter-blog-single-sidebar',
		'description'   => esc_html__( 'Add single blog widgets here.', 'buconz-starter' ),
		'before_widget' => '<div id="%1$s" class="single-widget widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Widget 1', 'buconz-starter' ),
		'id'            => 'buconz-starter-footer-1',
		'description'   => esc_html__( 'Add footer widget here.', 'buconz-starter' ),
		'before_widget' => '<div id="%1$s" class="single-widget f-link widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Widget 2', 'buconz-starter' ),
		'id'            => 'buconz-starter-footer-2',
		'description'   => esc_html__( 'Add footer widget here.', 'buconz-starter' ),
		'before_widget' => '<div id="%1$s" class="single-widget f-link widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Widget 3', 'buconz-starter' ),
		'id'            => 'buconz-starter-footer-3',
		'description'   => esc_html__( 'Add footer widget here.', 'buconz-starter' ),
		'before_widget' => '<div id="%1$s" class="single-widget f-link widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Widget 4', 'buconz-starter' ),
		'id'            => 'buconz-starter-footer-4',
		'description'   => esc_html__( 'Add footer widget here.', 'buconz-starter' ),
		'before_widget' => '<div id="%1$s" class="single-widget f-link widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'buconz_starter_widgets_init' );

function buconz_starter_wpdocs_custom_excerpt_length( $length ) {
	if ( is_admin() ) return $length;
    $excerptlength = absint(get_theme_mod('buconz_starter_post_excerpt',22));
    return $excerptlength;
}
add_filter( 'excerpt_length', 'buconz_starter_wpdocs_custom_excerpt_length', 999 );


/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';
require get_template_directory() . '/inc/buconz-starter-comment-template.php';
require get_template_directory() . '/inc/buconz-starter-scripts-styles.php';
require get_template_directory() . '/inc/tgm/recommended-plugins.php';
require get_template_directory() . '/inc/template-tags.php';
require get_template_directory() . '/inc/custom-header.php';
require get_template_directory() . '/inc/customizer.php';
